
function S = midpoint (f,estremi,N)

% Uso:
%   S = midpoint (f,estremi,N)
%
% Dati di ingresso:
%   f:       funzione vettoriale;
%   estremi: vettore riga con componenti gli
%            estremi "a", "b" di integrazione;
%   N:       numero intero positivo (punti medi).
%
% Dati di uscita:
%   S:       approssimazione di integrale(f,a,b).

if N <= 0, S=NaN; return; end
if not(N == floor(N)), S=NaN; return; end
a=estremi(1); b=estremi(2);
if a >= b, S=NaN; return; end
h=(b-a)/N;
k=1:N;
x=a-h/2+h*k; % vedi nota in calce sulle alternative
y=feval(f,x);
S=((b-a)/N)*sum(y);





